##############################################
Keysight E36312A Triple Output Power Supply
##############################################

.. autoclass:: pymeasure.instruments.keysight.KeysightE36312A
    :members:
    :show-inheritance:
    :inherited-members:

.. autoclass:: pymeasure.instruments.keysight.keysightE36312A.VoltageChannel
    :members:
    :show-inheritance:
